require("libs/camera")
require("libs/vector")
require("game/init")
require("game/tools")
require("game/game")
require("game/units")
require("game/draw")
require("game/keys")
require("game/tutorial")

function love.load()
	win_w = love.graphics.getWidth()
	win_h = love.graphics.getHeight()
	love.graphics.setBackgroundColor(190,190,190)
	love.graphics.setColor( 255,255,255,255 )
	r = 52 	--radius
	w = 2*r --width
	s = 3/2*r --width of 'source' rectangle representation 
	h = math.sqrt(3)*r --total height
	max_hex = 30
	mid_hex = math.floor(max_hex/2) --just in case i decide to change max_hex later
	camera = Camera()
	c_x, c_y = math.floor(mid_hex*s + w/2), math.floor(mid_hex*h+mid_hex%2*(h/2) + h/2)
	print(mid_hex, "mid")
	world= {}
	world["width"] = s*max_hex + 1/2*r--remember each hex is offset just a bit
	world["height"] = h*max_hex + h/2
	neighbors_odd = {{0,-1},{1,0},{1,1},{0,1},{-1,1},{-1,0}}
	neighbors_even = {{0,-1},{1,-1},{1,0},{0,1},{-1,0},{-1,-1}}
	quadImage = love.graphics.newImage('hex.png')
	setW = quadImage:getWidth()
	setH = quadImage:getHeight()
	hex = love.graphics.newQuad(19, 22, w, h+1, setW, setH)
	crater = love.graphics.newQuad(141, 23, w, h+1, setW, setH)
	hauler = love.graphics.newQuad(270, 23, w, h+1, setW, setH)
	surveyer = love.graphics.newQuad(383, 23, w, h+1, setW, setH)
	platform = love.graphics.newQuad(19, 152, w, h+1, setW, setH)
	crater_sb = love.graphics.newSpriteBatch( quadImage, 150 )
	ore_sb = love.graphics.newSpriteBatch( quadImage, 500 )
	small_font = love.graphics.newFont(12)
	medium_font = love.graphics.newFont(16)
	large_font = love.graphics.newFont(20)
	cursor = "none"
	main_menu = true
	show_tutorial = false
end

function love.update(dt)
	if main_menu ~= true then
		if shuttle_launch < shuttle_launch_at then
			x_m, y_m = camera:mousepos():unpack()
			i_, j_ = rectToHex(x_m,y_m) 	--game/tools.lua
			checkcursor()					--game/tooks.lua
			checkCamera()					--game/tools.lua
			if animate_move == true then
				animateMoves(dt)			 --game/game.lua
			end
		else 
			buySell()
		end
	else
		if show_tutorial == true then
			 checkTutorialCursor ()
		else
			mainMenu()
		end
	end
end

function love.draw()
	if main_menu == false then
		if shuttle_launch < shuttle_launch_at then
			love.graphics.setFont( small_font)
			camera:predraw()
			if cursor == "none" then
				love.graphics.setColor( 255,0,0,255 )
			elseif cursor == "move" --[[or cursor == "select"]] then
				love.graphics.setColor( 0,0,255,255 )
			elseif cursor == "select" then
				love.graphics.setColor( 0,0,255,255 )
			end
			if show_hex == true then
				love.graphics.drawq(quadImage, hex,i_*s, j_*h+i_%2*(h/2))
				love.graphics.print( "("..i_..","..j_..")", i_*s+r-15, 10+j_*h + i_%2*(h/2))
			end
			if show_hex == false and cursor == "select" or cursor == "hover" then
				love.graphics.drawq(quadImage, hex,i_*s, j_*h+i_%2*(h/2))
				love.graphics.print( "("..i_..","..j_..")", i_*s+r-15, 10+j_*h + i_%2*(h/2))
			end
			love.graphics.draw( crater_sb )
			drawEquip()
			drawBuildings()
			love.graphics.setColor(255,255,255,255)
			if show_survey == true then
				for name ,sub in pairs(surveyed) do
					love.graphics.drawq(quadImage, hex,sub[1][1]*s, sub[1][2]*h+sub[1][1]%2*(h/2))
					love.graphics.print(sub[1][3], sub[1][1]*s+7, sub[1][2]*h + sub[1][1]%2*(h/2) + h/2)
				end
			end
			if show_ore == true then
				love.graphics.draw( ore_sb )
				for i,v in ipairs(ore) do
					love.graphics.print(v.density, v.hex_i*s+7, v.hex_j*h + v.hex_i%2*(h/2) + h/2)
				end
			end
			camera:postdraw()
			printInfo()
			if show_controls == true then
				printControls()
			end
		else
			love.graphics.setFont( large_font)
			shuttleDraw()
		end
	else
		if show_tutorial == true then
			love.graphics.setFont( large_font )
			printTurorial()
		else
			love.graphics.setFont( large_font)
			mainMenuDraw()
		end
	end
end

function love.keyreleased( key )
	if main_menu ~= true then
		if shuttle_launch < shuttle_launch_at then
			mainKeyPress( key )		--game/keys.lua
		else
			shuttleKeyPress( key )	--game/keys.lua
		end
	else
		mainMenuKeyPress( key )		--games/keys.lua
	end
end

function love.mousereleased(x,y,button)
	if main_menu ~= true then
		if shuttle_launch < shuttle_launch_at then
			mainMousePressed( x,y,button )
		else
			shuttleMousePressed( x,y,button )
		end
	else
		if show_tutorial == true then
			tutorialMousePressed(  x,y,button )
		else
			mainMenuMousePressed( x,y,button )
		end
	end
end